@@ -1,5 +1,5 @@
 #
-# $Id: Online2.pm 349 2011-03-26 13:12:44Z gomor $
+# $Id: Online2.pm 353 2012-09-12 18:15:33Z gomor $
 #
 package Net::Frame::Dump::Online2;
 use strict;
@@ -28,7 +28,6 @@ BEGIN {
 
 use Net::Frame::Dump qw(:consts);
 
-use Carp;
 use Net::Pcap;
 use Time::HiRes qw(gettimeofday);
 use Net::Frame::Layer qw(:subs);
@@ -37,9 +36,8 @@ sub _checkWin32 { return 1; }
 
 sub _checkOther {
    if ($>) {
-      warn("Must be EUID 0 (or equivalent) to open a device for live ".
-           "capture.\n");
-      return;
+      die("[-] Net::Frame::Dump::Online2: Must be EUID 0 (or equivalent) to ".
+          "open a device for live capture\n");
    }
    return 1;
 }
@@ -54,7 +52,7 @@ sub new {
    );
 
    if (!defined($self->dev)) {
-      warn("You MUST pass `dev' attribute\n");
+      print("[-] ".__PACKAGE__.": You MUST pass `dev' attribute\n");
       return;
    }
 
@@ -77,7 +75,7 @@ sub start {
       \$err,
    );
    unless ($pd) {
-      warn("@{[(caller(0))[3]]}: open_live: $err\n");
+      print("[-] ".__PACKAGE__.": open_live: $err\n");
       return;
    }
 
@@ -85,23 +83,23 @@ sub start {
    my $mask = 0;
    Net::Pcap::lookupnet($self->dev, \$net, \$mask, \$err);
    if ($err) {
-      warn("@{[(caller(0))[3]]}: lookupnet: $err\n");
+      print("[!] ".__PACKAGE__.": lookupnet: $err\n");
    }
 
    my $fcode;
    if (Net::Pcap::compile($pd, \$fcode, $self->filter, 0, $mask) < 0) {
-      warn("@{[(caller(0))[3]]}: compile: ". Net::Pcap::geterr($pd). "\n");
+      print("[-] ".__PACKAGE__.": compile: ". Net::Pcap::geterr($pd). "\n");
       return;
    }
 
    if (Net::Pcap::setfilter($pd, $fcode) < 0) {
-      warn("@{[(caller(0))[3]]}: setfilter: ". Net::Pcap::geterr($pd). "\n");
+      print("[-] ".__PACKAGE__.": setfilter: ". Net::Pcap::geterr($pd). "\n");
       return;
    }
 
    my $r = Net::Pcap::setnonblock($pd, 1, \$err);
    if ($r == -1) {
-      warn("@{[(caller(0))[3]]}: setnonblock: $err\n");
+      print("[-] ".__PACKAGE__.": setnonblock: $err\n");
       return;
    }
 
@@ -135,7 +133,7 @@ sub getStats {
    my $self = shift;
 
    if (!defined($self->_pcapd)) {
-      carp("@{[(caller(0))[3]]}: unable to get stats, no pcap descriptor ".
+      print("[-] ".__PACKAGE__.": unable to get stats, no pcap descriptor ".
            "opened.\n");
       return;
    }
@@ -353,7 +351,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2011, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006-2012, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
